@@ -24,24 +24,6 @@ class AddColorFormatter(logging.Formatter):
         )
         return color + record.levelname + "\033[1;0m: " + msg
 
-@click.command("discover", help="Discover pixies in a package.")
-@click.option('-p', '--package', default='.', help='Package to run.')
-def discover_cli(package):
-    user_config_file = os.path.realpath(os.path.expanduser('~/.pixie/config.yaml'))
-    user_config = utils.read_yaml(user_config_file, {})
-    library = user_config.get('library', {})
-
-    runtime = PixieConsoleRuntime()
-    aliases = engine.discover(runtime, {}, package)
-    library[package] = aliases
-    user_config['library'] = library
-
-    utils.save_yaml(user_config, user_config_file)
-
-    for alias_name in aliases:
-        alias = aliases[alias_name]
-        click.echo(f'discovered {alias_name}: {alias["description"]}')
-
 
 def get_aliases():
     user_config_file = os.path.realpath(os.path.expanduser('~/.pixie/config.yaml'))
@@ -56,13 +38,50 @@ def get_aliases():
     return aliases
 
 
-def get_aliases_completion(ctx, param, incomplete):
+def get_library_packages():
+    user_config_file = os.path.realpath(os.path.expanduser('~/.pixie/config.yaml'))
+    user_config = utils.read_yaml(user_config_file, {})
+    library = user_config.get('library', {})
+
+    package_names = []
+    for package_name in library:
+        package_names.append(package_name)
+    return package_names
+
+
+def complete_library_packages(ctx, param, incomplete):
+    package_names = list(get_library_packages())
+    return [
+        name for name in package_names if name.startswith(incomplete)
+    ]
+
+
+def complete_library_aliases(ctx, param, incomplete):
     aliases = list(get_aliases())
     return [
         name for name in aliases if name.startswith(incomplete)
     ]
 
 
+@click.command("discover", help="Discover pixies in a package.")
+@click.option('-p', '--package', default='.', help='Package to run.', shell_complete=complete_library_packages)
+def discover_cli(package):
+    user_config_file = os.path.realpath(os.path.expanduser('~/.pixie/config.yaml'))
+    user_config = utils.read_yaml(user_config_file, {})
+    library = user_config.get('library', {})
+
+    runtime = PixieConsoleRuntime()
+    aliases = engine.discover(runtime, {}, package)
+    library[package] = aliases
+    user_config['library'] = library
+
+    utils.save_yaml(user_config, user_config_file)
+
+    for alias_name in aliases:
+        alias = aliases[alias_name]
+        click.echo(f'discovered {colored(alias_name, "green")}: {alias["description"]}')
+
+
 @click.command("list", help="List all discovered pixies.")
 def list_cli():
     user_config_file = os.path.realpath(os.path.expanduser('~/.pixie/config.yaml'))
@@ -78,7 +97,7 @@ def list_cli():
 
 
 @click.command("run", help="Used to run a pixie job.")
-@click.argument('job', shell_complete=get_aliases_completion)
+@click.argument('job', shell_complete=complete_library_aliases)
 @click.option('-p', '--package', default='.', help='Package to run.')
 @click.option('-s', '--script', default='.pixie.yaml', help='Path to the pixie script.')
 @click.option('-c', '--context', multiple=True, help='Context values to set.')
